@@ -53,6 +53,8 @@ extern "C" {
     fn tree_sitter_dart() -> ts::Language;
     fn tree_sitter_elisp() -> ts::Language;
     fn tree_sitter_elixir() -> ts::Language;
+    fn tree_sitter_gleam() -> ts::Language;
+    fn tree_sitter_elm() -> ts::Language;
     fn tree_sitter_go() -> ts::Language;
     fn tree_sitter_haskell() -> ts::Language;
     fn tree_sitter_janet_simple() -> ts::Language;
@@ -70,6 +72,8 @@ extern "C" {
     fn tree_sitter_scala() -> ts::Language;
     fn tree_sitter_tsx() -> ts::Language;
     fn tree_sitter_typescript() -> ts::Language;
+    fn tree_sitter_yaml() -> ts::Language;
+    fn tree_sitter_zig() -> ts::Language;
 }
 
 // TODO: begin/end and object/end.
@@ -240,6 +244,34 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Gleam => {
+            let language = unsafe { tree_sitter_gleam() };
+            TreeSitterConfig {
+                name: "Gleam",
+                language,
+                atom_nodes: ["string"].into(),
+                delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../vendor/highlights/gleam.scm"),
+                )
+                .unwrap(),
+            }
+        }
+        Elm => {
+            let language = unsafe { tree_sitter_elm() };
+            TreeSitterConfig {
+                name: "Elm",
+                language,
+                atom_nodes: vec!["string_constant_expr"].into_iter().collect(),
+                delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../vendor/highlights/elm.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Go => {
             let language = unsafe { tree_sitter_go() };
             TreeSitterConfig {
@@ -523,6 +555,42 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Yaml => {
+            let language = unsafe { tree_sitter_yaml() };
+            TreeSitterConfig {
+                name: "YAML",
+                language,
+                atom_nodes: (vec![
+                    "string_scalar",
+                    "double_quote_scalar",
+                    "single_quote_scalar",
+                ])
+                .into_iter()
+                .collect(),
+                delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")]),
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../vendor/highlights/yaml.scm"),
+                )
+                .unwrap(),
+            }
+        }
+        Zig => {
+            let language = unsafe { tree_sitter_zig() };
+            TreeSitterConfig {
+                name: "Zig",
+                language,
+                atom_nodes: (vec!["STRINGLITERALSINGLE"]).into_iter().collect(),
+                delimiter_tokens: (vec![("{", "}"), ("[", "]"), ("(", ")")])
+                    .into_iter()
+                    .collect(),
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../vendor/highlights/zig.scm"),
+                )
+                .unwrap(),
+            }
+        }
     }
 }
 
@@ -553,6 +621,9 @@ fn tree_highlights(
     if let Some(idx) = config.highlight_query.capture_index_for_name("constant") {
         keyword_ish_capture_ids.push(idx);
     }
+    if let Some(idx) = config.highlight_query.capture_index_for_name("boolean") {
+        keyword_ish_capture_ids.push(idx);
+    }
     if let Some(idx) = config
         .highlight_query
         .capture_index_for_name("constant.builtin")
@@ -564,6 +635,9 @@ fn tree_highlights(
     if let Some(idx) = config.highlight_query.capture_index_for_name("string") {
         string_capture_ids.push(idx);
     }
+    if let Some(idx) = config.highlight_query.capture_index_for_name("character") {
+        string_capture_ids.push(idx);
+    }
 
     let mut type_capture_ids = vec![];
     if let Some(idx) = config.highlight_query.capture_index_for_name("type") {
@@ -619,20 +693,18 @@ fn print_cursor(src: &str, cursor: &mut ts::TreeCursor, depth: usize) {
         let node = cursor.node();
         node.end_position();
 
+        let formatted_node = format!(
+            "{} {} - {}",
+            node.kind().replace('\n', "\\n"),
+            node.start_position(),
+            node.end_position()
+        );
+
         if node.child_count() == 0 {
             let node_src = &src[node.start_byte()..node.end_byte()];
-            println!(
-                "{}{} {:?}",
-                "  ".repeat(depth),
-                format!("{:?}", node).replace('\n', "\\n"),
-                node_src
-            );
+            println!("{}{} {:?}", "  ".repeat(depth), formatted_node, node_src);
         } else {
-            println!(
-                "{}{}",
-                "  ".repeat(depth),
-                format!("{:?}", node).replace('\n', "\\n"),
-            );
+            println!("{}{}", "  ".repeat(depth), formatted_node,);
         }
 
         if cursor.goto_first_child() {
